@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Dict
 from asf_search.exceptions import CMRError
 from asf_search.constants.INTERNAL import CMR_HOST, CMR_COLLECTIONS_PATH
 
@@ -6,7 +6,7 @@ import requests
 
 
 def get_campaigns(data) -> Dict:
-    """Queries CMR Collections endpoint for 
+    """Queries CMR Collections endpoint for
     collections associated with the given platform
 
     :param data: a dictionary with required keys:
@@ -14,8 +14,7 @@ def get_campaigns(data) -> Dict:
 
     :return: Dictionary containing CMR umm_json response
     """
-    response = requests.post(f'https://{CMR_HOST}{CMR_COLLECTIONS_PATH}',
-                             data=data)
+    response = requests.post(f'https://{CMR_HOST}{CMR_COLLECTIONS_PATH}', data=data)
     if response.status_code != 200:
         raise CMRError(f'CMR_ERROR {response.status_code}: {response.text}')
 
