@@ -2,6 +2,6 @@ class RepairEntry:
     def __init__(self, report_type: str, report: str) -> None:
         self.report_type = report_type
         self.report = report
-    
+
     def __str__(self) -> str:
-        return f"{self.report_type}: {self.report}"
+        return f'{self.report_type}: {self.report}'
